==> cueplot-0.0.2-src.tar.gz: cueplot-0.0.2-src/gui/opt/LogScaleOptionWidget.h <==
/*
 * Cueplot: a GUI front end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef LOG_SCALE_OPTION_WIDGET_INCLUDED
#define LOG_SCALE_OPTION_WIDGET_INCLUDED

#include "OptionWidget.h"

class LogScale;

#include <QList>
class QCheckBox;
class QLineEdit;

class LogScaleOptionWidget : public OptionWidget
{
	Q_OBJECT

	public:
		LogScaleOptionWidget(QWidget *parent = 0);
		~LogScaleOptionWidget();

		void construct();

	private:
		// don't implement these
		LogScaleOptionWidget(const LogScaleOptionWidget &);
		LogScaleOptionWidget &operator=(const LogScaleOptionWidget &);

		void init();
		void apply();
		void setWidget();
		LogScale *logScale;
		QList<QCheckBox *> logScaleCheckBoxList;
		QList<QLineEdit *> baseLineEditList;
};
#endif // LOG_SCALE_OPTION_WIDGET_INCLUDED

==> cueplot-0.0.3-src.tar.gz: cueplot-0.0.3-src/gui/opt/LogScaleOptionWidget.h <==
/*
 * Cueplot: a GUI front-end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef LOG_SCALE_OPTION_WIDGET_INCLUDED
#define LOG_SCALE_OPTION_WIDGET_INCLUDED

#include "OptionWidget.h"

class LogScale;

#include <QtCore/QList>
class QCheckBox;
class QLineEdit;

class LogScaleOptionWidget : public OptionWidget
{
	Q_OBJECT

	public:
		explicit LogScaleOptionWidget(QWidget *parent = 0);
		~LogScaleOptionWidget();

		void construct();

	private:
		// don't implement these
		LogScaleOptionWidget(const LogScaleOptionWidget &);
		LogScaleOptionWidget &operator=(const LogScaleOptionWidget &);

		void init();
		void apply();
		void setWidget();
		LogScale *logScale;
		QList<QCheckBox *> logScaleCheckBoxList;
		QList<QLineEdit *> baseLineEditList;
};
#endif // LOG_SCALE_OPTION_WIDGET_INCLUDED
